      DOUBLE PRECISION FUNCTION PD2VAL(DEG,DEGMAX,C0,TG1,TG2,T1,T2)
C
C     ******************************************************************
C
C                                                           From Padua2D
C
C                                       Marco Caliari and Marco Vianello
C                             Department of Pure and Applied Mathematics
C                                            University of Padua (Italy)
C                                        {mcaliari,marcov}@math.unipd.it
C
C                                                      Stefano De Marchi
C                                         Department of Computer Science
C                                           University of Verona (Italy)
C                                              stefano.demarchi@univr.it
C
C                                                        June 19th, 2007
C
C       This function returns the value of the interpolant at (TG1,TG2).
C     C0 is the matrix of the coefficients computed by PADUA2.
C
C     ******************************************************************
C
C     PARAMS type                i=input, o=output, a=auxiliary           
C     
C     DEG    integer             i degree of approximation
C     DEGMAX integer             i maximum degree allowed. DEGMAX + 1 is
C                                  the leading dimension of C0
C     C0     double(0:DEG,0:DEG) i matrix C0 of the coefficients
C     TG1    double              i first coordinate of the
C                                   target point
C     TG2    double              i second coordinate of the
C                                   target point
C     T1     double(0:DEG)       a Normalized Chebyshev polynomials at
C                                  the first coordinate of target point
C     T2     double(0:DEG)       a Normalized Chebyshev polynomials at
C                                  the second coordinate of target point
C
C     **********************************************************************
C
      INTEGER DEG,DEGMAX
      DOUBLE PRECISION TG1,TG2,C0(0:DEGMAX,0:DEG),T1(0:DEG),T2(0:DEG)
C
C     LOCALS
C
      INTEGER I
      DOUBLE PRECISION DDOT
      EXTERNAL DDOT
C     
C     Compute Chebyshev polynomials at the target point
C     
      CALL CHEB(DEG,TG1,T1,1.0D0)
      CALL CHEB(DEG,TG2,T2,1.0D0)
C
C     Evaluate the interpolant
C
      PD2VAL = 0.0D0
      DO 10 I = DEG,0,-1
         PD2VAL = PD2VAL + DDOT(I + 1,T1(0),1,C0(0,DEG - I),1) 
     1        * T2(DEG - I)
 10   CONTINUE
      RETURN
      END
